@@ -28,7 +28,7 @@ public:
     Item * next ();
     void update (Item * i, int failures, int time);
 
-    void prepare ();
+    void prepare (bool reset = false);
 
 private:
     QList<Item*> numbers;
